<!--To help us understand and resolve your issue, please fill out the form to
the best of your ability.-->
<!--You can feel free to delete the sections that do not apply.-->

### Bug report

**Bug summary**

<!--A short 1-2 sentences that succinctly describes the bug-->

**Code for reproduction**

<!--A minimum code snippet required to reproduce the bug, also minimizing the
number of dependencies required.-->

<!-- If you need to use a data file to trigger the issue you're having, consider
using one of the sample datasets from the
ytree collection (https://girder.hub.yt/#collection/59835a1ee2a67400016a2cda)
on the yt hub (https://girder.hub.yt/). If your issue cannot be triggered using
a public dataset, you can use the yt curldrop
(https://docs.hub.yt/services.html#curldrop) to share data files. Please include
a link to the dataset in the issue if you use the curldrop.-->

```python
# Paste your code here
#
#
```

**Actual outcome**

<!--The output produced by the above code, which may be a screenshot, console
output, etc.-->

```
# If applicable, paste the console output here
#
#
```

**Expected outcome**

<!--A description of the expected outcome from the code snippet-->
<!--If this used to work in an earlier version of ytree, please note the
version it used to work on-->

**Version Information**
<!--Please specify your platform and versions of the relevant libraries you are
using:-->
  * Operating System:
  * Python Version:
  * ytree version:
  * Other Libraries (if applicable):
  
